@@ -1,18 +1,19 @@
-import io, json, sys, re, csv, fileinput
+import io, json, sys, re, csv, logging
 from types import SimpleNamespace
-from typing import Union
+from logging import Formatter
+from logging.handlers import RotatingFileHandler
 from fastcore.foundation import L
-
 from datetime import datetime
-import nbformat
-from nbformat import NotebookNode
 from rich import box
 from rich.table import Table
 from rich.console import Console
+from rich.logging import RichHandler
 from fastcore.basics import ifnone, listify, store_attr
 from fastcore.xtras import run
 from pathlib import Path
 
+LOGFORMAT = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+LOGFORMAT_RICH = "%(message)s"
 
 # rich
 def create_table(columns=["Notebook Path", "Status", "Run Time", "Colab"], xtra_cols=None) -> Table:
@@ -65,6 +66,22 @@ def csv_to_md(csv_file_path, delimiter=";"):
     file.close()
 
 
+STATUS = SimpleNamespace(
+    ok="[green]Ok[/green]:heavy_check_mark:", fail="[red]Fail[/red]", skip="[green]Skipped[/green]:heavy_check_mark:"
+)
+
+
+def _format_row(fname: Path, status: str, time: str, xtra_col=None, fname_only: bool = True) -> tuple:
+    "Format one row for a rich.Table"
+
+    formatted_status = getattr(STATUS, status.lower())
+    fname = fname.name if fname_only else fname
+    row = (str(fname), formatted_status, f"{int(time)}s")
+    if len(listify(xtra_col)) > 0:
+        row += (str(xtra_col),)
+    return row
+
+
 class RichLogger:
     "A simple logger that logs to a file and the rich console"
 
@@ -72,24 +89,42 @@ class RichLogger:
         self.data = []
         self.links = []
         self.console = Console(width=width, record=True)
-        print(f"CONSOLE.is_terminal(): {self.console.is_terminal}")
+        rh = RichHandler(console=self.console)
+        rh.setFormatter(Formatter(LOGFORMAT_RICH))
 
         # beautiful rich table
         store_attr()
-
-        self.log(f"Writing output to {out_file}")
+        logging.basicConfig(
+            level=logging.ERROR,
+            format=LOGFORMAT,
+            handlers=[
+                rh,
+                RotatingFileHandler("errors.log", maxBytes=1024 * 1024 * 10, backupCount=10),  # 10Mb
+            ],
+        )
+        self.logger = logging.getLogger("rich")
+        self.info(f"CONSOLE.is_terminal(): {self.console.is_terminal}")
+        self.info(f"Writing output to {out_file}")
 
     def writerow(self, row, colab_link=None):
         self.data.append(row)
         self.links.append(colab_link)
 
-    def to_csv(self, out_file, delimiter=";"):
+    def writerow_incolor(self, fname, status, time, colab_link):
+        "Same as write row, but color status"
+        row = _format_row(fname, status, time)
+        self.writerow(row, colab_link)
+
+    def to_csv(self, out_file, delimiter=";", format_link=True):
         self.csv_file = open(out_file, "w", newline="")
         self.csv_writer = csv.writer(self.csv_file, delimiter=delimiter)
         # write header
         self.csv_writer.writerow(self.columns)
         for row, link in zip(self.data, self.links):
-            fname = self._format_colab_link_md(link, row[0])
+            if format_link:
+                fname = self._format_colab_link_md(link, row[0])
+            else:
+                fname = row[0]
             self.csv_writer.writerow([fname] + [remove_rich_format(e) for e in row[1:]])
         self.csv_file.close()
 
@@ -105,10 +140,23 @@ class RichLogger:
         csv_file = Path(out_file).with_suffix(".csv")
         self.to_csv(csv_file)
         csv_to_md(csv_file)
-        self.log(f"The markdown file [red]{out_file}[/red] has been created!!!")
+        self.info(f"Output table saved to [red]{out_file}[/red]")
 
-    def log(self, text):
-        self.console.print(text)
+    @property
+    def info(self):
+        return self.logger.info
+
+    @property
+    def warning(self):
+        return self.logger.warning
+
+    @property
+    def exception(self):
+        return self.logger.exception
+
+    @property
+    def error(self):
+        return self.logger.error
 
     @staticmethod
     def _format_colab_link(colab_link, fname):
@@ -135,7 +183,7 @@ class RichLogger:
                 table.close()
             if message is not None:
                 file.write(message)
-        self.log(f"Creating github issue via file: {github_issue_file}")
+        self.info(f"Creating github issue via file: {github_issue_file}")
 
 
 # nb
@@ -146,7 +194,7 @@ def is_nb(fname: Path):
 
 def find_nbs(path: Path):
     "Get all nbs on path recursively"
-    path = Path(path)
+    path = Path(path).absolute()
     if is_nb(path):
         return [path]
     return L([nb for nb in path.rglob("*.ipynb") if is_nb(nb)]).sorted()
@@ -161,17 +209,6 @@ def print_output(notebook):  # pragma: no cover
     output_stream.flush()
 
 
-def read_nb(fname: Union[Path, str]) -> NotebookNode:
-    "Read the notebook in `fname`."
-    with open(Path(fname), "r", encoding="utf8") as f:
-        return nbformat.reads(f.read(), as_version=4)
-
-
-def write_nb(notebook, fname: Union[Path, str]):
-    "Dump `notebook` to `fname`"
-    nbformat.write(notebook, str(fname), version=4)
-
-
 CellType = SimpleNamespace(code="code", md="markdown")
 
 
@@ -251,7 +288,11 @@ def git_current_branch(fname) -> str:
 
 def git_main_name(fname) -> str:
     "Get the name of master/main branch"
-    branches = run(f"git -C {Path(fname).parent} branch")
+    try:
+        branches = run(f"git -C {Path(fname).parent} branch")
+    except Exception as e:
+        print(f"Probably not in a git repo: {e}")
+        return "master"
     return "main" if "main" in branches else "master"
 
 
@@ -275,9 +316,9 @@ def git_origin_repo(fname):
 def git_local_repo(fname):
     "Get local github repo path"
     fname = Path(fname)
-    repo = git_origin_repo(fname)
-    for p in fname.parents:
-        if p.match(f"*/{repo}"):
+    repo_name = git_origin_repo(fname)
+    for p in fname.absolute().parents:
+        if p.match(f"*/{repo_name}"):
             break
     return p
 
